import django.core.serializers.json
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('postoffice_django', '0002_add_bulk_field'),
    ]

    operations = [
        migrations.AlterField(
            model_name='publishingerror',
            name='payload',
            field=django.db.models.JSONField(
                encoder=django.core.serializers.json.DjangoJSONEncoder),
        ),
        migrations.AlterField(
            model_name='publishingerror',
            name='attributes',
            field=django.db.models.JSONField(
                encoder=django.core.serializers.json.DjangoJSONEncoder,
                null=True
            ),
        ),
    ]



from django.core.serializers.json import DjangoJSONEncoder
from django.db import models
from django.db.models import JSONField


class PublishingError(models.Model):
    topic = models.CharField(max_length=100)
    payload = JSONField(encoder=DjangoJSONEncoder)
    attributes = JSONField(null=True, encoder=DjangoJSONEncoder)
    bulk = models.BooleanField(default=False)
    error = models.CharField(max_length=255, default='')
    created_at = models.DateTimeField(auto_now_add=True)
